@@ -94,5 +94,5 @@ class EmoTFIDF:
                     em_frequencies[a] = new_fre
         sum_values = sum(em_frequencies.values())
         for key in em_frequencies.keys():
-            em_percent.update({key: float(em_frequencies[key]) / float(sum_values)})
+            em_percent.update({key: round(float(em_frequencies[key]) / float(sum_values), 3)})
         self.em_tfidf = em_percent
